#!/usr/bin/env python
# -*- coding: utf-8 -*-

# author: Pocholo
# date: 8/6/23

# Comments directed to http://gimpchat.com

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

import math
import os, sys,time 
from gimpfu import *

def pm_asian_fan(color, leafColor, leafGrad):

    #Initiates the temporary state
    pdb.gimp_context_push()
    pdb.gimp_context_set_defaults()
    
############################## Create the wood ###########################################################################

    #Background
    img = pdb.gimp_image_new(1000, 800, RGB)
    backLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, backLayer, None, 0)
    pdb.gimp_context_set_foreground("#ffffff")
    pdb.gimp_drawable_fill(backLayer, FILL_FOREGROUND)
    
    #Create a new image
    size = 500
    woodLayer = pdb.gimp_layer_new(img, size, size, RGB_IMAGE, "Wood pattern", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, woodLayer, None, 0)
    pdb.gimp_context_set_foreground("#6f432a")
    pdb.gimp_drawable_fill(woodLayer, FILL_FOREGROUND)
    
    #Create the noise layer
    cloudLayer = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "Noise cloud", 100, LAYER_MODE_SOFTLIGHT)
    pdb.gimp_image_insert_layer(img, cloudLayer, None, 0)
    pdb.gimp_drawable_fill(cloudLayer, FILL_TRANSPARENT)
    pdb.plug_in_solid_noise(img, cloudLayer, FALSE, FALSE, 0, 15, 2, 2)
    
    #Create the design
    woodLayer = pdb.gimp_image_merge_down(img, cloudLayer, CLIP_TO_IMAGE)
    pdb.plug_in_ripple(img, woodLayer, 320, 800, 0, 1, 1, TRUE, TRUE)
    
    pdb.plug_in_hsv_noise(img, woodLayer, 8, 2, 4, 255)
    pdb.plug_in_wind(img, woodLayer, 15, 0, 45, 0, 0)
    pdb.plug_in_wind(img, woodLayer, 15, 1, 45, 0, 0)
    pdb.plug_in_make_seamless(img, woodLayer)
    
    #Copy to clipboard
    non_empty = pdb.gimp_edit_copy(woodLayer)
    pdb.gimp_image_remove_layer(img, woodLayer)
    pdb.gimp_context_set_pattern("Clipboard Image")
    pdb.gimp_edit_bucket_fill(backLayer, BUCKET_FILL_PATTERN, LAYER_MODE_NORMAL, 100, 255, FALSE, img.width/2, img.height/2)

    pdb.gimp_display_new(img)

    #Create the leaf (fan paper)
    leafLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Leaf", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, leafLayer, None, 0)
    pdb.gimp_drawable_fill(leafLayer, FILL_TRANSPARENT)
    
    num_segs = 80
    segs = [38,509, 67,440, 90,375, 143,328, 177,272, 237,242, 284,197, 348,181, 407,149, 472,154, 
            536,141, 597,160, 663,159, 719,196, 783,216, 819,265, 878,297, 900,356, 944,411, 965,472, 
            705,563, 698,536, 680,516, 665,493, 641,474, 628,459, 602,450, 576,437, 551,434, 523,426, 
            501,434, 470,432, 447,443, 418,451, 404,466, 376,483, 365,505, 344,527, 336,549, 324,576]
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs)
    
    pdb.gimp_context_set_foreground("#ffffff")
    pdb.gimp_drawable_edit_fill(leafLayer, FILL_FOREGROUND)
    
    
    if color==1:
        pdb.gimp_context_set_foreground(leafColor)
        pdb.gimp_drawable_edit_fill(leafLayer, FILL_FOREGROUND)
        pdb.gimp_selection_none(img)
    
    if color==2:
        pdb.gimp_context_set_gradient(leafGrad)
        pdb.gimp_drawable_edit_gradient_fill(leafLayer, 
                                                     2,  #gradient type - radial
                                                     0,  #offset
                                                   TRUE,  #super sample
                                                     3,  #supersample-max depth
                                                  0.20,  #supersample-threshole
                                                  TRUE,  #dither
                                                   517,  #x1
                                                   625,  #y1
                                                   517,  #x2
                                                   150)  #y2
        
    #Create the slips top
    slipsLayer2 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Fan slips #2", 75, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, slipsLayer2, None, 0)
    pdb.gimp_drawable_fill(slipsLayer2, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(2)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_dynamics("Dynamics Off")
    pdb.gimp_paintbrush_default(slipsLayer2, 4, [90,375, 344,527])
    pdb.gimp_paintbrush_default(slipsLayer2, 4, [177,272, 376,483])
    pdb.gimp_paintbrush_default(slipsLayer2, 4, [284,197, 418,451])
    pdb.gimp_paintbrush_default(slipsLayer2, 4, [407,149, 470,432])
    pdb.gimp_paintbrush_default(slipsLayer2, 4, [536,141, 523,426])
    pdb.gimp_paintbrush_default(slipsLayer2, 4, [663,159, 576,437])
    pdb.gimp_paintbrush_default(slipsLayer2, 4, [783,216, 628,459])
    pdb.gimp_paintbrush_default(slipsLayer2, 4, [878,297, 665,493])
    pdb.gimp_paintbrush_default(slipsLayer2, 4, [944,411, 698,536])
    pdb.gimp_levels(slipsLayer2, 
                              0,   #channel - histogram-value
                              0,   #low_input 
                             70,   #high_input 
                           1.00,   #gamma 
                              0,  #low_output
                            255)  #high_output 
   
    #Create the slips bottom
    slipsLayer1 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Fan slips #1", 45, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, slipsLayer1, None, 0)
    pdb.gimp_drawable_fill(slipsLayer1, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground("#000000")
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(3)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_paintbrush_default(slipsLayer1, 4, [67,440, 336,549])
    pdb.gimp_paintbrush_default(slipsLayer1, 4, [143,328, 365,505])    
    pdb.gimp_paintbrush_default(slipsLayer1, 4, [237,242, 404,466])    
    pdb.gimp_paintbrush_default(slipsLayer1, 4, [348,181, 447,443])
    pdb.gimp_paintbrush_default(slipsLayer1, 4, [472,154, 501,434])    
    pdb.gimp_paintbrush_default(slipsLayer1, 4, [597,160, 551,434])    
    pdb.gimp_paintbrush_default(slipsLayer1, 4, [719,196, 602,450])    
    pdb.gimp_paintbrush_default(slipsLayer1, 4, [819,265, 641,474])    
    pdb.gimp_paintbrush_default(slipsLayer1, 4, [900,356, 680,516])
    pdb.plug_in_gauss(img, slipsLayer1, 14, 14, 1)
    
    #Create the shades
    num_segs = 10
    segs1 = [705,563, 965,472, 944,411, 698,536, 705,563]
    segs2 = [680,516, 900,356, 878,297, 665,493, 680,516]
    segs3 = [641,474, 819,265, 783,216, 628,459, 641,474]
    segs4 = [602,450, 719,196, 663,159, 576,437, 602,450]
    segs5 = [551,434, 597,160, 536,141, 524,426, 551,434]
    segs6 = [501,434, 472,154, 407,149, 470,432, 501,434]
    segs7 = [447,443, 348,181, 284,197, 418,451, 447,443]
    segs8 = [404,466, 237,242, 177,272, 376,483, 404,466]
    segs9 = [365,505, 143,328, 90,375, 344,527, 365,505]
    pdb.gimp_context_set_foreground("#000000")
    shadeLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Shades", 35, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, shadeLayer, None, 0)
    pdb.gimp_drawable_fill(shadeLayer, FILL_TRANSPARENT)
    
    #Shade 1
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs1)
    pdb.gimp_drawable_edit_fill(shadeLayer, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    #Shade 2
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs2)
    pdb.gimp_drawable_edit_fill(shadeLayer, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    #Shade 3
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs3)
    pdb.gimp_drawable_edit_fill(shadeLayer, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    #Shade 4
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs4)
    pdb.gimp_drawable_edit_fill(shadeLayer, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    #Shade 5
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs5)
    pdb.gimp_drawable_edit_fill(shadeLayer, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    #Shade 6
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs6)
    pdb.gimp_drawable_edit_fill(shadeLayer, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    #Shade 7
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs7)
    pdb.gimp_drawable_edit_fill(shadeLayer, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    #Shade 8
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs8)
    pdb.gimp_drawable_edit_fill(shadeLayer, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    #Shade 9
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs9)
    pdb.gimp_drawable_edit_fill(shadeLayer, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    
    #Merge the slips and the shades
    pdb.gimp_item_set_visible(leafLayer, FALSE)
    pdb.gimp_item_set_visible(backLayer, FALSE)
    slipsLayer = pdb.gimp_image_merge_visible_layers(img, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(slipsLayer, "Slips") 
    pdb.gimp_item_set_visible(leafLayer, TRUE)
    pdb.gimp_item_set_visible(backLayer, TRUE)
    
    #create a stick brush, copy the brush to clipboard and delete it
    sticksBrush = pdb.gimp_layer_new(img, 107, 392, RGBA_IMAGE, "Layer", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, sticksBrush, None, 0)
    pdb.gimp_drawable_fill(sticksBrush, FILL_TRANSPARENT)
    num_segs = 10
    segs = [28,8, 79,8, 61,386, 42,386, 28,8]
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_image_select_polygon(img, 2, num_segs, segs)
    pdb.gimp_drawable_edit_fill(sticksBrush, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    non_empty = pdb.gimp_edit_copy(sticksBrush)
    pdb.gimp_image_remove_layer(img, sticksBrush)
      
    #Stick 1
    sticksLayer1 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Thin Guard", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, sticksLayer1, None, 2)
    pdb.gimp_drawable_fill(sticksLayer1, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_paintbrush_default(sticksLayer1, 4, [59,480, 517,625])
    pdb.gimp_brushes_set_brush("2. Block 02")
    pdb.gimp_context_set_brush_size(80)
    pdb.gimp_context_set_brush_aspect_ratio(3.5)
    pdb.gimp_context_set_brush_angle(16.80)
    pdb.gimp_paintbrush_default(sticksLayer1, 2, [517,625])
    #Stick 2
    sticksLayer2 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Stick #2", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, sticksLayer2, None, 2)
    pdb.gimp_drawable_fill(sticksLayer2, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_paintbrush_default(sticksLayer2, 4, [111,365, 517,625])
    pdb.gimp_brushes_set_brush("2. Block 02")
    pdb.gimp_context_set_brush_size(80)
    pdb.gimp_context_set_brush_aspect_ratio(3.50)
    pdb.gimp_context_set_brush_angle(35.00)
    pdb.gimp_paintbrush_default(sticksLayer2, 2, [517,625])
    #Stick 3
    sticksLayer3 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Stick #3", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, sticksLayer3, None, 2)
    pdb.gimp_drawable_fill(sticksLayer3, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_paintbrush_default(sticksLayer3, 4, [204,270, 517,625])
    pdb.gimp_brushes_set_brush("2. Block 02")
    pdb.gimp_context_set_brush_size(80)
    pdb.gimp_context_set_brush_aspect_ratio(3.50)
    pdb.gimp_context_set_brush_angle(51.00)
    pdb.gimp_paintbrush_default(sticksLayer3, 2, [517,625])
    #Stick 4
    sticksLayer4 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Stick #4", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, sticksLayer4, None, 2)
    pdb.gimp_drawable_fill(sticksLayer4, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_paintbrush_default(sticksLayer4, 4, [312,197, 517,625])
    pdb.gimp_brushes_set_brush("2. Block 02")
    pdb.gimp_context_set_brush_size(80)
    pdb.gimp_context_set_brush_aspect_ratio(3.50)
    pdb.gimp_context_set_brush_angle(65.00)
    pdb.gimp_paintbrush_default(sticksLayer4, 2, [517,625])
    #Stick 5
    sticksLayer5 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Stick #5", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, sticksLayer5, None, 2)
    pdb.gimp_drawable_fill(sticksLayer5, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_paintbrush_default(sticksLayer5, 4, [430,160, 517,625])
    pdb.gimp_brushes_set_brush("2. Block 02")
    pdb.gimp_context_set_brush_size(80)
    pdb.gimp_context_set_brush_aspect_ratio(3.50)
    pdb.gimp_context_set_brush_angle(79.00)
    pdb.gimp_paintbrush_default(sticksLayer5, 2, [517,625])
    #Stick 6
    sticksLayer6 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Stick #6", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, sticksLayer6, None, 2)
    pdb.gimp_drawable_fill(sticksLayer6, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_paintbrush_default(sticksLayer6, 4, [552,158, 517,625])
    pdb.gimp_brushes_set_brush("2. Block 02")
    pdb.gimp_context_set_brush_size(80)
    pdb.gimp_context_set_brush_aspect_ratio(3.50)
    pdb.gimp_context_set_brush_angle(95.00)
    pdb.gimp_paintbrush_default(sticksLayer6, 2, [517,625])
    #Stick 7
    sticksLayer7 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Stick #7", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, sticksLayer7, None, 2)
    pdb.gimp_drawable_fill(sticksLayer7, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_paintbrush_default(sticksLayer7, 4, [678,177, 517,625])
    pdb.gimp_brushes_set_brush("2. Block 02")
    pdb.gimp_context_set_brush_size(80)
    pdb.gimp_context_set_brush_aspect_ratio(3.50)
    pdb.gimp_context_set_brush_angle(110.00)
    pdb.gimp_paintbrush_default(sticksLayer7, 2, [517,625])
    #Stick 8
    sticksLayer8 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Stick #8", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, sticksLayer8, None, 2)
    pdb.gimp_drawable_fill(sticksLayer8, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_paintbrush_default(sticksLayer8, 4, [788,233, 517,625])
    pdb.gimp_brushes_set_brush("2. Block 02")
    pdb.gimp_context_set_brush_size(80)
    pdb.gimp_context_set_brush_aspect_ratio(3.50)
    pdb.gimp_context_set_brush_angle(125.00)
    pdb.gimp_paintbrush_default(sticksLayer8, 2, [517,625])
    #Stick 9
    sticksLayer9 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Stick #9", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, sticksLayer9, None, 2)
    pdb.gimp_drawable_fill(sticksLayer9, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_paintbrush_default(sticksLayer9, 4, [880,320, 517,625])
    pdb.gimp_brushes_set_brush("2. Block 02")
    pdb.gimp_context_set_brush_size(80)
    pdb.gimp_context_set_brush_aspect_ratio(3.50)
    pdb.gimp_context_set_brush_angle(140.00)
    pdb.gimp_paintbrush_default(sticksLayer9, 2, [517,625])
    
    #Guard stick
    guardLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Thick Guard", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, guardLayer, None, 0)
    pdb.gimp_drawable_fill(guardLayer, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("Clipboard Image")
    pdb.gimp_context_set_brush_size(485)
    pdb.gimp_context_set_brush_aspect_ratio(-14.00)
    pdb.gimp_context_set_brush_angle(68)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#a1774e")
    pdb.gimp_paintbrush_default(guardLayer, 2, [735,539])
    pdb.gimp_brushes_set_brush("2. Block 02")
    pdb.gimp_context_set_brush_size(80)
    pdb.gimp_context_set_brush_aspect_ratio(3.50)
    pdb.gimp_context_set_brush_angle(161.00)
    pdb.gimp_paintbrush_default(guardLayer, 2, [517,625])
    
    #Make the leaf, slip and background layers invisible
    pdb.gimp_item_set_visible(leafLayer, FALSE)
    pdb.gimp_item_set_visible(slipsLayer, FALSE)
    pdb.gimp_item_set_visible(backLayer, FALSE)
    

############# Make the sick more wooden realistic #############################################

    #Fill selection with noise
    layerlist = img.layers
    processlist=[]
    emptycheck =[]
    for i in range(len(layerlist)):
        visible = pdb.gimp_item_get_visible(layerlist[i])
        if visible:
            processlist.append(layerlist[i])
    count = 0
    for i in processlist:
        pdb.gimp_image_select_item(img, 2, i)
        pdb.plug_in_hsv_noise(img, i, 2, 3, 10, 50)
        pdb.gimp_selection_none(img)
        count+=1    
    
    #Motion blur
    pdb.gimp_image_select_item(img, 2, sticksLayer1)
    pdb.plug_in_mblur(img, sticksLayer1, 0, 8, 17, 517, 625) #0 for linear
    pdb.gimp_image_select_item(img, 2, sticksLayer2)
    pdb.plug_in_mblur(img, sticksLayer2, 0, 8, 35, 517, 625) #0 for linear
    pdb.gimp_image_select_item(img, 2, sticksLayer3)
    pdb.plug_in_mblur(img, sticksLayer3, 0, 8, 51, 517, 625) #0 for linear
    pdb.gimp_image_select_item(img, 2, sticksLayer4)
    pdb.plug_in_mblur(img, sticksLayer4, 0, 8, 65, 517, 625) #0 for linear
    pdb.gimp_image_select_item(img, 2, sticksLayer5)
    pdb.plug_in_mblur(img, sticksLayer5, 0, 8, 79, 517, 625) #0 for linear
    pdb.gimp_image_select_item(img, 2, sticksLayer6)
    pdb.plug_in_mblur(img, sticksLayer6, 0, 8, 95, 517, 625) #0 for linear
    pdb.gimp_image_select_item(img, 2, sticksLayer7)
    pdb.plug_in_mblur(img, sticksLayer7, 0, 8, 110, 517, 625) #0 for linear
    pdb.gimp_image_select_item(img, 2, sticksLayer8)
    pdb.plug_in_mblur(img, sticksLayer8, 0, 8, 125, 517, 625) #0 for linear
    pdb.gimp_image_select_item(img, 2, sticksLayer9)
    pdb.plug_in_mblur(img, sticksLayer9, 0, 8, 140, 517, 625) #0 for linear
    pdb.gimp_image_select_item(img, 2, guardLayer)
    pdb.plug_in_mblur(img, guardLayer, 0, 8, 161, 517, 625) #0 for linear
    pdb.gimp_selection_none(img)
    
    #Create a little shadow
    layerlist = img.layers
    processlist=[]
    emptycheck =[]
    for i in range(len(layerlist)):
        visible = pdb.gimp_item_get_visible(layerlist[i])
        if visible:
            processlist.append(layerlist[i])
    count = 0
    for i in processlist:
        pdb.script_fu_drop_shadow(img, i, 0, 0, 10, ("Black"), 100, FALSE)
        count+=1    
    
    #Merge the stick with a shadows and rename the layers
    d_shadow = pdb.gimp_image_merge_down(img, guardLayer, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(d_shadow, "Thick Guard")
    d_shadow1 = pdb.gimp_image_merge_down(img, sticksLayer9, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(d_shadow1, "Stick #9")
    d_shadow2 = pdb.gimp_image_merge_down(img, sticksLayer8, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(d_shadow2, "Stick #8")
    d_shadow3 = pdb.gimp_image_merge_down(img, sticksLayer7, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(d_shadow3, "Stick #7")
    d_shadow4 = pdb.gimp_image_merge_down(img, sticksLayer6, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(d_shadow4, "Stick #6")
    d_shadow5 = pdb.gimp_image_merge_down(img, sticksLayer5, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(d_shadow5, "Stick #5")
    d_shadow6 = pdb.gimp_image_merge_down(img, sticksLayer4, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(d_shadow6, "Stick #4")
    d_shadow7 = pdb.gimp_image_merge_down(img, sticksLayer3, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(d_shadow7, "Stick #3")
    d_shadow8 = pdb.gimp_image_merge_down(img, sticksLayer2, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(d_shadow8, "Stick #2")
    d_shadow9 = pdb.gimp_image_merge_down(img, sticksLayer1, EXPAND_AS_NECESSARY)
    pdb.gimp_item_set_name(d_shadow9, "Thin Guard")        
    
    #Make all the layers visible
    layerlist = img.layers
    pdb.gimp_item_set_visible(leafLayer, TRUE)
    pdb.gimp_item_set_visible(backLayer, TRUE)
    pdb.gimp_item_set_visible(slipsLayer, TRUE)
    pdb.gimp_item_set_visible(d_shadow, TRUE)
    
    #Guard stick glare
    glareLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Guard glare", 7, LAYER_MODE_LINEAR_LIGHT)
    pdb.gimp_image_insert_layer(img, glareLayer, None, 0)
    pdb.gimp_drawable_fill(glareLayer, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(3)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_foreground("#ffffff")
    pdb.gimp_paintbrush_default(glareLayer, 4, [538,618, 868,486])
    pdb.gimp_image_select_item(img, 2, d_shadow)
    pdb.plug_in_mblur(img, glareLayer, 0, 55, 160, 517, 625) #0 for linear
    pdb.gimp_selection_none(img)
    d_shadow = pdb.gimp_image_merge_down(img, glareLayer, EXPAND_AS_NECESSARY)
    
    #Rivet
    rivetLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Rivet", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, rivetLayer, None, 0)
    pdb.gimp_drawable_fill(rivetLayer, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground("#544133")
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_paintbrush_default(rivetLayer, 2, [517,625])
    pdb.plug_in_emboss(img, rivetLayer, 90, 30, 25, FALSE)
    
    #Rivet glare
    rivetglare = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Layer", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, rivetglare, None, 0)
    pdb.gimp_drawable_fill(rivetglare, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 050")
    pdb.gimp_context_set_brush_size(6)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.10)
    pdb.gimp_context_set_brush_hardness(0.500)
    pdb.gimp_context_set_brush_force(0.500)
    pdb.gimp_paintbrush_default(rivetglare, 2, [517,623])
    rivetLayer = pdb.gimp_image_merge_down(img, rivetglare, EXPAND_AS_NECESSARY)
    
    #Consolidate the effect
    pdb.gimp_item_set_visible(backLayer, FALSE)
    resultLayer = pdb.gimp_layer_new_from_visible(img, img, "Hand Fan")
    pdb.gimp_image_insert_layer(img, resultLayer, None, 0)
    pdb.gimp_item_set_visible(backLayer, TRUE)
    pdb.script_fu_drop_shadow(img, resultLayer, 0, 0, 25, ("Black"), 100, FALSE)
  
    #Resets the previous user defaults
    pdb.gimp_context_pop()  	
  
register(
    "pm_asian_fan",
    "Create an Asian Fan",
    "Create an Asian Fan",
    "Pocholo",
    "Pocholo",
    "2023",
    "Create an Asian Fan",
    "",
    [	
    (PF_OPTION,  "color", "Color Option:", 0 ,["Plain White", "Color", "Gradient"]),
    (PF_COLOR, "leafColor", "Leaf Color:", ("#c90000")),
    (PF_GRADIENT, "leafGrad", "Leaf Gradient", "Pastels"),
    ],
    [],
    pm_asian_fan, menu="<Image>/Python-Fu/Special Effects/"),   
main()	